@@ -19,11 +19,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Ovid.py,v 1.3 1999/08/25 11:07:33 gobry Exp $
+# $Id: Ovid.py,v 1.4 1999/09/24 07:21:20 gobry Exp $
 
 # Extension module for Ovid files
 
-from Pyblio import Base, Open, Types, Fields
+from Pyblio import Base, Autoload, Types, Fields
 
 import sys, re, string
 
@@ -323,6 +323,6 @@ def my_open (entity, check):
     return base
 
     
-Open.register ('Ovid', {'open'  : my_open})
+Autoload.register ('format', 'Ovid', {'open'  : my_open})
 
 
