@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Utils.py,v 1.4 1999/09/15 09:29:28 gobry Exp $
+# $Id: Utils.py,v 1.5 1999/09/27 15:56:24 gobry Exp $
 
 from gtk import *
 from gnome.ui import *
@@ -40,13 +40,14 @@ def set_cursor (self, name):
 
     self.get_window ().set_cursor (cursor [name])
         
-    # is this normal ??
-    threads_leave ()
+    # not necessary with Gtk+-1.2.5
+    # threads_leave ()
     
     while events_pending ():
         mainiteration (FALSE)
     
-    threads_enter ()
+    # not necessary with Gtk+-1.2.5
+    # threads_enter ()
     return
 
 def popup_add (menu, item, action = None, argument = None):
